@@ -1,8 +1,7 @@
+from simplenn.layer import Layer
 from typing import List
 from typing import Union
 
-from simplenn.layer import Layer
-
 
 class SGD:
     def __init__(
@@ -37,7 +36,7 @@ class SGD:
         layer.W_momentum = W_update
         layer.b_momentum = b_update
 
-    def learn(self, layers: List[Layer]):
+    def step(self, layers: List[Layer]):
         lr = self.get_adjusted_lr()
         for layer in layers:
 
